contexttools.ContextMark
========================

.. inheritance-diagram:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark
   :private-bases:

.. autoclass:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.effective_context

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.target_context

Methods
-------

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.attach

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.detach

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__eq__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__str__

   .. note:: Inherited from `__builtin__.object`
